@@ -1866,6 +1866,11 @@ ebews_store_contact_items (EBookBackendEws *ebews,
 		EEwsItem *item;
 
 		item = (EEwsItem *) l->data;
+		if (e_ews_item_get_item_type (item) == E_EWS_ITEM_TYPE_ERROR) {
+			g_object_unref (item);
+			continue;
+		}
+
 		contact = e_contact_new ();
 
 		if (!distribution_list) {
@@ -1907,6 +1912,11 @@ ebews_get_vcards_list (GSList *new_items,
 		gchar *vcard_string = NULL;
 
 		item = (EEwsItem *) l->data;
+		if (e_ews_item_get_item_type (item) == E_EWS_ITEM_TYPE_ERROR) {
+			g_object_unref (item);
+			continue;
+		}
+
 		contact = e_contact_new ();
 
 		for (i = 0; i < G_N_ELEMENTS (mappings); i++) {
@@ -2103,10 +2113,13 @@ ebews_fetch_items (EBookBackendEws *ebews,
 		EEwsItem *item = (EEwsItem *) l->data;
 		const gchar *d_name;
 		const EwsId *id;
-		EwsMailbox *mb = g_new0 (EwsMailbox, 1);
+		EwsMailbox *mb;
 		GSList *members = NULL;
 		gboolean includes_last;
 
+		if (e_ews_item_get_item_type (item) == E_EWS_ITEM_TYPE_ERROR)
+			continue;
+
 		id = e_ews_item_get_id (item);
 		mb = g_new0 (EwsMailbox, 1);
 		mb->item_id = (EwsId *) id;
@@ -2669,11 +2682,20 @@ e_book_backend_ews_get_backend_property (EBookBackend *backend,
 	g_return_if_fail (prop_name != NULL);
 
 	if (g_str_equal (prop_name, CLIENT_BACKEND_PROPERTY_CAPABILITIES)) {
-		/* do-initialy-query is enabled for system address book also, so that we get the
-		 * book_view, which is needed for displaying cache update progress.
-		 * and null query is handled for system address book.
-		 */
-		e_data_book_respond_get_backend_property (book, opid, NULL, "net,bulk-removes,do-initial-query,contact-lists");
+		EBookBackendEws *ebews;
+
+		ebews = E_BOOK_BACKEND_EWS (backend);
+		g_return_if_fail (ebews != NULL);
+
+		if (ebews->priv->is_gal) {
+			e_data_book_respond_get_backend_property (book, opid, NULL, "net,bulk-removes,contact-lists");
+		} else {
+			/* do-initialy-query is enabled for system address book also, so that we get the
+			 * book_view, which is needed for displaying cache update progress.
+			 * and null query is handled for system address book.
+			 */
+			e_data_book_respond_get_backend_property (book, opid, NULL, "net,bulk-removes,do-initial-query,contact-lists");
+		}
 	} else if (g_str_equal (prop_name, BOOK_BACKEND_PROPERTY_REQUIRED_FIELDS)) {
 		e_data_book_respond_get_backend_property (book, opid, NULL, e_contact_field_name (E_CONTACT_FILE_AS));
 	} else if (g_str_equal (prop_name, BOOK_BACKEND_PROPERTY_SUPPORTED_FIELDS)) {
